package fr.lri.hcc.ilda.touchtokens;

/*
 *   Authors: Caroline Appert (caroline.appert@lri.fr)
 *   Copyright (c) Univ. Paris-Sud XI, 2015. All Rights Reserved
 *   Licensed under the GNU LGPL. For full terms see the file COPYING.
*/

import android.app.Activity;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Rect;
import android.util.AttributeSet;

import java.util.ArrayList;

/**
 * Created by appert on 03/09/15.
 */
public class TestView extends TouchTokenView {

    protected String tokenID;
    protected ArrayList<TouchPoint> points;

    protected Paint recoPaint = new Paint();

    public TestView(Context context) {
        super(context);
    }

    public TestView(Context context, AttributeSet attrs) {
        super(context, attrs);
    }

    @Override
    public void onTokenDown(String tokenID, ArrayList<TouchPoint> points, double viewWidthMm, double viewHeightMm) {
        this.tokenID = tokenID;
        this.points = points;
        Activity host = (Activity) this.getContext();
        host.runOnUiThread(new Runnable() {
            @Override
            public void run() {
                invalidate();
            }
        });
    }

    @Override
    public void onTokenMoved(String tokenID, ArrayList<TouchPoint> points, double viewWidthMm, double viewHeightMm) {
        this.tokenID = tokenID;
        this.points = points;
        Activity host = (Activity) this.getContext();
        host.runOnUiThread(new Runnable() {
            @Override
            public void run() {
                invalidate();
            }
        });
    }

    @Override
    public void onTokenUp(String tokenID, ArrayList<TouchPoint> points, double viewWidthMm, double viewHeightMm) {
        this.tokenID = tokenID;
        this.points = points;
        this.tokenID = null;
        Activity host = (Activity) this.getContext();
        host.runOnUiThread(new Runnable() {
            @Override
            public void run() {
                invalidate();
            }
        });
    }

    @Override
    protected void onDraw(Canvas canvas) {
        recoPaint.setColor(Color.BLACK);
        recoPaint.setTextSize(40);
        super.onDraw(canvas);

        if(tokenID == null) {
            return;
        }

        TouchPoint centroid = TouchTokenRecognizer.centroid(points);
        canvas.drawCircle(
                (int)(centroid.x * getWidth()),
                (int)(centroid.y * getHeight()),
                40, recoPaint);

        String textTokenID = tokenID;
        String textLocation = "("+(int)(centroid.x * getWidth())+", "+(int)(centroid.y * getHeight())+")";
        Rect boundsTextTokenID = new Rect();
        recoPaint.getTextBounds(textTokenID, 0, textTokenID.length(), boundsTextTokenID);
        Rect boundsTextLocation = new Rect();
        recoPaint.getTextBounds(textLocation, 0, textLocation.length(), boundsTextLocation);
        canvas.drawText(textTokenID, 10, getHeight() - 10 - boundsTextLocation.height() - 10 - boundsTextTokenID.height(), recoPaint);
        canvas.drawText(textLocation, 10, getHeight() - 10 - boundsTextLocation.height(), recoPaint);
    }
}
